==> ec2-1.15.0.DEVPREVIEW-sources.jar: software/amazon/awscdk/services/ec2/CfnSpotFleetProps.java <==
package software.amazon.awscdk.services.ec2;

/**
 * Properties for defining a `AWS::EC2::SpotFleet`.
 * 
 * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-spotfleet.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.19.0 (build 7c562bc)", date = "2019-10-28T12:23:14.028Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
public interface CfnSpotFleetProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * `AWS::EC2::SpotFleet.SpotFleetRequestConfigData`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-spotfleet.html#cfn-ec2-spotfleet-spotfleetrequestconfigdata
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    java.lang.Object getSpotFleetRequestConfigData();

    /**
     * @return a {@link Builder} of {@link CfnSpotFleetProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CfnSpotFleetProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    public static final class Builder {
        private java.lang.Object spotFleetRequestConfigData;

        /**
         * Sets the value of SpotFleetRequestConfigData
         * @param spotFleetRequestConfigData `AWS::EC2::SpotFleet.SpotFleetRequestConfigData`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder spotFleetRequestConfigData(software.amazon.awscdk.core.IResolvable spotFleetRequestConfigData) {
            this.spotFleetRequestConfigData = spotFleetRequestConfigData;
            return this;
        }

        /**
         * Sets the value of SpotFleetRequestConfigData
         * @param spotFleetRequestConfigData `AWS::EC2::SpotFleet.SpotFleetRequestConfigData`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder spotFleetRequestConfigData(software.amazon.awscdk.services.ec2.CfnSpotFleet.SpotFleetRequestConfigDataProperty spotFleetRequestConfigData) {
            this.spotFleetRequestConfigData = spotFleetRequestConfigData;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnSpotFleetProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public CfnSpotFleetProps build() {
            return new Jsii$Proxy(spotFleetRequestConfigData);
        }
    }

    /**
     * An implementation for {@link CfnSpotFleetProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CfnSpotFleetProps {
        private final java.lang.Object spotFleetRequestConfigData;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.setObjRef(objRef);
            this.spotFleetRequestConfigData = this.jsiiGet("spotFleetRequestConfigData", java.lang.Object.class);
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        private Jsii$Proxy(java.lang.Object spotFleetRequestConfigData) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.spotFleetRequestConfigData = java.util.Objects.requireNonNull(spotFleetRequestConfigData, "spotFleetRequestConfigData is required");
        }

        @Override
        public java.lang.Object getSpotFleetRequestConfigData() {
            return this.spotFleetRequestConfigData;
        }

        @Override
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("spotFleetRequestConfigData", om.valueToTree(this.getSpotFleetRequestConfigData()));
            return obj;
        }

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CfnSpotFleetProps.Jsii$Proxy that = (CfnSpotFleetProps.Jsii$Proxy) o;

            return this.spotFleetRequestConfigData.equals(that.spotFleetRequestConfigData);
        }

        @Override
        public int hashCode() {
            int result = this.spotFleetRequestConfigData.hashCode();
            return result;
        }
    }
}

==> ec2-1.16.0.DEVPREVIEW-sources.jar: software/amazon/awscdk/services/ec2/CfnSpotFleetProps.java <==
package software.amazon.awscdk.services.ec2;

/**
 * Properties for defining a `AWS::EC2::SpotFleet`.
 * 
 * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-spotfleet.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.20.2 (build faba0be)", date = "2019-11-11T17:17:50.769Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.ec2.$Module.class, fqn = "@aws-cdk/aws-ec2.CfnSpotFleetProps")
@software.amazon.jsii.Jsii.Proxy(CfnSpotFleetProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
public interface CfnSpotFleetProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * `AWS::EC2::SpotFleet.SpotFleetRequestConfigData`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-spotfleet.html#cfn-ec2-spotfleet-spotfleetrequestconfigdata
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    java.lang.Object getSpotFleetRequestConfigData();

    /**
     * @return a {@link Builder} of {@link CfnSpotFleetProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CfnSpotFleetProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    public static final class Builder {
        private java.lang.Object spotFleetRequestConfigData;

        /**
         * Sets the value of SpotFleetRequestConfigData
         * @param spotFleetRequestConfigData `AWS::EC2::SpotFleet.SpotFleetRequestConfigData`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder spotFleetRequestConfigData(software.amazon.awscdk.core.IResolvable spotFleetRequestConfigData) {
            this.spotFleetRequestConfigData = spotFleetRequestConfigData;
            return this;
        }

        /**
         * Sets the value of SpotFleetRequestConfigData
         * @param spotFleetRequestConfigData `AWS::EC2::SpotFleet.SpotFleetRequestConfigData`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder spotFleetRequestConfigData(software.amazon.awscdk.services.ec2.CfnSpotFleet.SpotFleetRequestConfigDataProperty spotFleetRequestConfigData) {
            this.spotFleetRequestConfigData = spotFleetRequestConfigData;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnSpotFleetProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public CfnSpotFleetProps build() {
            return new Jsii$Proxy(spotFleetRequestConfigData);
        }
    }

    /**
     * An implementation for {@link CfnSpotFleetProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CfnSpotFleetProps {
        private final java.lang.Object spotFleetRequestConfigData;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.spotFleetRequestConfigData = this.jsiiGet("spotFleetRequestConfigData", java.lang.Object.class);
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        private Jsii$Proxy(final java.lang.Object spotFleetRequestConfigData) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.spotFleetRequestConfigData = java.util.Objects.requireNonNull(spotFleetRequestConfigData, "spotFleetRequestConfigData is required");
        }

        @Override
        public java.lang.Object getSpotFleetRequestConfigData() {
            return this.spotFleetRequestConfigData;
        }

        @Override
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("spotFleetRequestConfigData", om.valueToTree(this.getSpotFleetRequestConfigData()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-ec2.CfnSpotFleetProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CfnSpotFleetProps.Jsii$Proxy that = (CfnSpotFleetProps.Jsii$Proxy) o;

            return this.spotFleetRequestConfigData.equals(that.spotFleetRequestConfigData);
        }

        @Override
        public int hashCode() {
            int result = this.spotFleetRequestConfigData.hashCode();
            return result;
        }
    }
}
